"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.trimFalseyKeys = exports.trimNullishKeys = exports.trimEmptyKeys = void 0;
const typechecker_1 = require("typechecker");
/** Trim nested keys which values are nullish, or zero-length arrays, sets, maps, and plain objects */
function trimEmptyKeys(obj) {
    if (!(0, typechecker_1.isPlainObject)(obj))
        return obj;
    for (const [key, value] of Object.entries(obj)) {
        if (value == null ||
            (Array.isArray(value) && value.length === 0) ||
            (value instanceof Set && value.size === 0) ||
            (value instanceof Map && value.size === 0)) {
            delete obj[key];
        }
        else if ((0, typechecker_1.isPlainObject)(value)) {
            if (Object.keys(trimEmptyKeys(obj[key])).length === 0)
                delete obj[key];
        }
    }
    return obj;
}
exports.trimEmptyKeys = trimEmptyKeys;
exports.default = trimEmptyKeys;
/** Trim nested keys which values are nullish and zero-length plain objects */
function trimNullishKeys(obj) {
    if (!(0, typechecker_1.isPlainObject)(obj))
        return obj;
    for (const [key, value] of Object.entries(obj)) {
        if (value == null) {
            delete obj[key];
        }
        else if ((0, typechecker_1.isPlainObject)(value)) {
            if (Object.keys(trimNullishKeys(obj[key])).length === 0)
                delete obj[key];
        }
    }
    return obj;
}
exports.trimNullishKeys = trimNullishKeys;
/** Trim nested keys which values are falsely and zero-length plain objects */
function trimFalseyKeys(obj) {
    if (!(0, typechecker_1.isPlainObject)(obj))
        return obj;
    for (const [key, value] of Object.entries(obj)) {
        if (!value) {
            delete obj[key];
        }
        else if ((0, typechecker_1.isPlainObject)(value)) {
            if (Object.keys(trimFalseyKeys(obj[key])).length === 0)
                delete obj[key];
        }
    }
    return obj;
}
exports.trimFalseyKeys = trimFalseyKeys;
